summaryrefslogtreecommitdiffstats
path: root/kopete
diff options
context:
space:
mode:
authorMichele Calgaro <[email protected]>2024-11-10 17:12:44 +0900
committerMichele Calgaro <[email protected]>2024-11-10 17:12:44 +0900
commit4b808f07f04092e84bb907c2d3a815406507409f (patch)
treef8ef865105d3621c2c4a04b620e3d3cd5ff57a87 /kopete
parent75436bb8cf554fa372ce66793b07af63ecda51a0 (diff)
downloadtdenetwork-4b808f07f04092e84bb907c2d3a815406507409f.tar.gz
tdenetwork-4b808f07f04092e84bb907c2d3a815406507409f.zip
Rename KUniqueApplication to TDEUniqueApplication
Signed-off-by: Michele Calgaro <[email protected]>
Diffstat (limited to 'kopete')
-rw-r--r--kopete/kopete/kopeteapplication.cpp10
-rw-r--r--kopete/kopete/kopeteapplication.h4
-rw-r--r--kopete/kopete/main.cpp2
3 files changed, 8 insertions, 8 deletions
diff --git a/kopete/kopete/kopeteapplication.h b/kopete/kopete/kopeteapplication.h
index 8490684e..ed363ed9 100644
--- a/kopete/kopete/kopeteapplication.h
+++ b/kopete/kopete/kopeteapplication.h
@@ -26,7 +26,7 @@
#include <tqguardedptr.h>
-#include <kuniqueapplication.h>
+#include <tdeuniqueapplication.h>
class KopeteWindow;
class TQSessionManager;
@@ -40,7 +40,7 @@ namespace Kopete
/**
* @author Duncan Mac-Vicar P. <[email protected]>
*/
-class KopeteApplication : public KUniqueApplication
+class KopeteApplication : public TDEUniqueApplication
{
TQ_OBJECT
diff --git a/kopete/kopete/main.cpp b/kopete/kopete/main.cpp
index 04656f8f..68218d78 100644
--- a/kopete/kopete/main.cpp
+++ b/kopete/kopete/main.cpp
@@ -98,7 +98,7 @@ int main( int argc, char *argv[] )
TDECmdLineArgs::init( argc, argv, &aboutData );
TDECmdLineArgs::addCmdLineOptions( options ); // Add our own options.
- KUniqueApplication::addCmdLineOptions();
+ TDEUniqueApplication::addCmdLineOptions();
KopeteApplication kopete;
new KIMIfaceImpl();
diff --git a/kopete/kopete/kopeteapplication.cpp b/kopete/kopete/kopeteapplication.cpp
index 263ed973..342b03f5 100644
--- a/kopete/kopete/kopeteapplication.cpp
+++ b/kopete/kopete/kopeteapplication.cpp
@@ -52,7 +52,7 @@
#endif
KopeteApplication::KopeteApplication()
-: KUniqueApplication( true, true, true )
+: TDEUniqueApplication( true, true, true )
{
m_isShuttingDown = false;
m_mainWindow = new KopeteWindow( 0, "mainWindow" );
@@ -274,18 +274,18 @@ int KopeteApplication::newInstance()
* The following three lines work around a problem that
* Kopete has since it has multiple main windows so
* qapp->mainWidget() returns 0, which breaks the normal
* KUniqueApplication::newInstance() behavior that raises
* the window when we run a new instance.
*
* 1. Set the main widget to the contact list window
- * 2. Call KUniqueApplication::newInstance()
+ * 2. Call TDEUniqueApplication::newInstance()
* 3. Set the main widget back to 0
*
* This little workaround fixes the problem. -Matt
*/
setMainWidget( m_mainWindow );
- int kUnitqAppReturnCode = KUniqueApplication::newInstance();
+ int kUnitqAppReturnCode = TDEUniqueApplication::newInstance();
setMainWidget( 0L );
return kUnitqAppReturnCode;
@@ -331,7 +331,7 @@ void KopeteApplication::quitKopete()
void KopeteApplication::commitData( TQSessionManager &sm )
{
m_isShuttingDown = true;
- KUniqueApplication::commitData( sm );
+ TDEUniqueApplication::commitData( sm );
}
#include "kopeteapplication.moc"
@@ -274,18 +274,18 @@ int KopeteApplication::newInstance()
* Kopete has since it has multiple main windows so
* qapp->mainWidget() returns 0, which breaks the normal
- * KUniqueApplication::newInstance() behavior that raises
+ * TDEUniqueApplication::newInstance() behavior that raises
* the window when we run a new instance.
*